@@ -10,9 +10,11 @@ use base qw(App::Followme::Module);
 use Cwd;
 use IO::Dir;
 use File::Spec::Functions qw(abs2rel rel2abs splitdir catfile no_upwards);
-use App::Followme::FIO;
 
-our $VERSION = "1.95";
+use App::Followme::FIO;
+use App::Followme::Web;
+
+our $VERSION = "1.96";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
@@ -38,6 +40,52 @@ sub run {
     return;
 }
 
+#----------------------------------------------------------------------
+# Return a flag indicating that recursion on folders is not needed
+
+sub no_recurse {
+    my ($self) = @_;
+
+    my $template_file = $self->get_template_name($self->{template_file});
+    my $template = fio_read_page($template_file);
+    die "Couldn't read template: $template_file" unless $template;
+
+    return web_has_variables($template, '@all_files', '@top_files');
+}
+
+#----------------------------------------------------------------------
+# Return true if each section in a file has been filled from the template
+
+sub sections_are_filled {
+    my ($self, $filename) = @_;
+
+    my $page = fio_read_page($filename);
+    return unless $page;
+    my $page_sections = web_parse_sections($page);
+
+    my $template_file = $self->get_template_name($self->{template_file});
+    my $template = fio_read_page($template_file);
+    die "Couldn't read template: $template_file" unless $template;
+    my $template_sections = web_parse_sections($template);
+
+    foreach my $name (keys %$template_sections) {
+        next unless $template_sections->{$name} =~ /\S/;
+        return unless $page_sections->{$name} =~ /\S/;
+    }
+
+    return 1;
+}
+
+#----------------------------------------------------------------------
+# Set exclude_index to true in the data package
+
+sub setup {
+    my ($self, %configuration) = @_;
+
+    $self->{data}{exclude_index} = 1;
+    return;
+}
+
 #----------------------------------------------------------------------
 # Find files in directory to convert and do that
 
@@ -45,17 +93,30 @@ sub update_folder {
     my ($self, $folder) = @_;
 
     my $index_file = $self->to_file($folder);
+    my $base_index_file = $self->to_file($self->{data}{base_directory}); 
+
     my $template_file = $self->get_template_name($self->{template_file});
-    my $newest_file = $self->{data}->build('newest_file', $index_file);
+    my $newest_file = $self->{data}->build('newest_file', $base_index_file);
 
-    unless (fio_is_newer($index_file, $template_file, @$newest_file)) {
-        my $page = $self->render_file($self->{template_file}, $index_file);
-        my $prototype_file = $self->find_prototype();
 
+    unless (fio_is_newer($index_file, $template_file, @$newest_file) &&
+            $self->sections_are_filled($index_file)) {
+
+        my $page = $self->render_file($self->{template_file}, $base_index_file);
+
+        my $prototype_file = $self->find_prototype($folder, 0);
         $page = $self->reformat_file($prototype_file, $index_file, $page);
         fio_write_page($index_file, $page);
     }
 
+    unless ($self->no_recurse) {
+        my $folders = $self->{data}->build('folders', $index_file);
+        foreach my $subfolder (@$folders) {
+            eval {$self->update_folder($subfolder)};
+            $self->check_error($@, $subfolder);
+        }
+    }
+
     return;
 }
 
